#
# login.py - a login wrapper
#
# Copyright 2013, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Martin Krizek <mkrizek@redhat.com>

import bunch
from flask import g, redirect


class GenericLogin(object):
    def __init__(self, drv):
        self.drv = drv

    def login(self, username=None, password=None, return_url=None, cancel_url=None):
        raise NotImplementedError('login() not implemented')

    def logout(self):
        raise NotImplementedError('logout() not implemented')


class FasOpenIDLogin(GenericLogin):
    def __init__(self, drv):
        super(FasOpenIDLogin, self).__init__(drv)
        self.user = None

    def login(self, username=None, password=None, return_url=None, cancel_url=None):
        ret = self.drv.login(username, password, return_url, cancel_url)
        self.user = g.fas_user
        return ret

    def logout(self):
        self.user = None
        return self.drv.logout()


class DevLogin(GenericLogin):
    def __init__(self, drv):
        super(DevLogin, self).__init__(drv)
        self.user = None

    def login(self, username=None, password=None, return_url=None, cancel_url=None):
        admin = bunch.Bunch(name='qa-admin')
        self.user = bunch.Bunch(username='developer', approved_memberships=[admin])

        if return_url is None:
            return_url = url_for('main.index')

        return redirect(return_url)

    def logout(self):
        self.user = None
